#!/bin/bash
# Install cephadm and podman if not present
rpm -qa | grep -qw podman  || dnf install -y podman
rpm -qa | grep -qw cephadm || dnf install -y https://download.ceph.com/rpm-octopus/el8/x86_64/cephadm-15.2.1-0.el8.x86_64.rpm
# Check if cluster already present
CHECK=$(cephadm ls | jq '.[0].name')
if [ $CHECK != "null" ];then
	echo "cluster is already present on system"
	exit 0
fi	
# Add ceph repo
cephadm add-repo --release octopus
cephadm install
# Install ceph-common and ceph-base on host to enable ceph cli
cephadm install ceph-common
# Bootstrap cluster on local host
mkdir /etc/ceph
PRIMARY_IP=$(ip route get 1 | head -1 | awk '{print $7}')
cephadm bootstrap --mon-ip $PRIMARY_IP --mgr-id $(hostname -s) --mon-id $(hostname -s) --allow-fqdn-hostname |& tee ~/cephadm.log
# Create osds using all available disks in system
ceph orch apply osd --all-available-devices
